@@ -102,15 +102,16 @@ class ResultsPublisher:
                 # enhanced_result = self._enhance_result_for_publishing(aggregated_result)
                 
                 # Produce message to Kafka
-                if self.kafka_handler.produce_message(message=aggregated_result, key=aggregated_result.get("aggregation_metadata", {}).get("stream_key")):
+                try:
+                    self.kafka_handler.produce_message(message=aggregated_result, key=aggregated_result.get("aggregation_metadata", {}).get("stream_key"))
                     self.stats["messages_produced"] += 1
                     # Extract stream key from camera_info for logging (new structure)
                     camera_info = aggregated_result.get('camera_info', {})
                     stream_key = camera_info.get('camera_name', 'unknown')
                     logging.debug(f"Successfully published camera_results for stream: {stream_key}")
-                else:
+                except Exception as exc:
                     self.stats["kafka_errors"] += 1
-                    self._record_error("Failed to produce aggregated result to Kafka")
+                    self._record_error(f"Failed to produce aggregated result to Kafka: {str(exc)}")
                 
                 # Mark task as done
                 self.final_results_queue.task_done()
