@@ -29,7 +29,9 @@ APP_NAME_TO_USECASE = {
     "concrete_crack_detection": "concrete_crack_detection",
     "lane_detection" : "lane_detection",
     "shelf_inventory" :"shelf_inventory",
-    "smoker_detection": "smoker_detection"
+    "smoker_detection": "smoker_detection",
+    "age_detection": "age_detection",
+    "defect_detection_products": "defect_detection_products"
 }
 
 APP_NAME_TO_CATEGORY = {
@@ -63,7 +65,9 @@ APP_NAME_TO_CATEGORY = {
     "concrete_crack_detection": "general",
     "lane_detection" : "traffic",
     "shelf_inventory" : "retail",
-    "smoker_detection": "general"
+    "smoker_detection": "general",
+    "age_detection": "general",
+    "defect_detection_products": "retail"
 }
 
 def get_usecase_from_app_name(app_name: str) -> str:
