@@ -755,7 +755,7 @@ class ConfigManager:
         except ImportError:
             return None
     
-    def bottle_defect_detection_config_class(self):
+    def defect_detection_products_config_class(self):
         """Register a configuration class for a use case."""
         try:
             from ..usecases.defect_detection_products import BottleDefectConfig
@@ -1383,7 +1383,7 @@ class ConfigManager:
                 alert_config = AlertConfig(**alert_config)
 
             config = AgeDetectionConfig(
-                category=category or "security",
+                category=category or "general",
                 usecase=usecase,
                 alert_config=alert_config,
                 **kwargs
