@@ -173,7 +173,7 @@ class PostProcessor:
         registry.register_use_case("parking_space", "parking_space_detection", ParkingSpaceUseCase)
         registry.register_use_case("environmental", "underwater_pollution_detection", UnderwaterPlasticUseCase)
         registry.register_use_case("pedestrian", "pedestrian_detection", PedestrianDetectionUseCase)  
-        registry.register_use_case("security", "age_detection", AgeDetectionUseCase)
+        registry.register_use_case("general", "age_detection", AgeDetectionUseCase)
         registry.register_use_case("weld", "weld_defect_detection", WeldDefectUseCase)
         registry.register_use_case("price_tag", "price_tag_detection", PriceTagUseCase)
         registry.register_use_case("mask_detection", "mask_detection", MaskDetectionUseCase)
@@ -320,6 +320,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, PriceTagUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, AgeDetectionUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, GenderDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, FashionDetectionUseCase):
@@ -358,6 +360,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, context, stream_info)
             elif isinstance(use_case, SmokerDetectionUseCase):
                 result = use_case.process(data, parsed_config, context, stream_info)
+            elif isinstance(use_case, BottleDefectUseCase):
+                result = use_case.process(data, parsed_config, context, stream_info)
 
             
             #Put all IMAGE based usecases here
