@@ -66,6 +66,7 @@ from .leaf import LeafConfig, LeafUseCase
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
 from .skin_cancer_classification_img import SkinCancerClassificationConfig, SkinCancerClassificationUseCase
 from .plaque_segmentation_img import PlaqueSegmentationConfig, PlaqueSegmentationUseCase
+from .smoker_detection import SmokerDetectionConfig, SmokerDetectionUseCase
 
 __all__ = [
     'PeopleCountingUseCase',
@@ -117,6 +118,7 @@ __all__ = [
     'LaneDetectionUseCase',
     'WindmillMaintenanceUseCase',
     'FlowerUseCase',
+    'SmokerDetectionUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
@@ -173,6 +175,7 @@ __all__ = [
     'LaneDetectionConfig',
     'WindmillMaintenanceConfig',
     'FlowerConfig',
+    'SmokerDetectionConfig',
 
 
 
