@@ -4,10 +4,11 @@ Fire and Smoke Detection use case implementation.
 This module provides a structured implementation of fire and smoke detection
 with counting, insights generation, alerting, and tracking.
 """
-from datetime import datetime, timezone
+from datetime import datetime, timezone, timedelta
 from typing import Any, Dict, List, Optional
 from dataclasses import dataclass, field
 import time
+import re
 
 from ..core.base import (
     BaseProcessor,
@@ -41,6 +42,9 @@ class FireSmokeConfig(BaseConfig):
     fire_smoke_categories: List[str] = field(
         default_factory=lambda: ["Fire", "Smoke"]
     )
+    target_categories: List[str] = field(
+        default_factory=lambda: ['Fire']
+    )
 
     alert_config: Optional[AlertConfig] = None
 
@@ -71,6 +75,8 @@ class FireSmokeConfig(BaseConfig):
         self.fire_smoke_categories = [cat.lower() for cat in self.fire_smoke_categories]
         if self.index_to_category:
             self.index_to_category = {k: v.lower() for k, v in self.index_to_category.items()}
+        if self.target_categories:
+                self.target_categories = [cat.lower() for cat in self.target_categories]
 
 
 
@@ -86,6 +92,7 @@ class FireSmokeUseCase(BaseProcessor):
 
         self.smoothing_tracker = None  # Required for bbox smoothing
         self._fire_smoke_recent_history = []
+        self.target_categories=['Fire']
 
         self._ascending_alert_list: List[int] = []
         self.current_incident_end_timestamp: str = "N/A"
@@ -131,6 +138,10 @@ class FireSmokeUseCase(BaseProcessor):
                 processed_data = apply_category_mapping(processed_data, config.index_to_category)
                 self.logger.debug("Applied category mapping")
 
+            if self.target_categories:
+                processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
+                self.logger.debug(f"Applied category filtering")
+
             # Step 3.5: BBox smoothing for fire/smoke
             if config.enable_smoothing:
                 if self.smoothing_tracker is None:
@@ -257,17 +268,22 @@ class FireSmokeUseCase(BaseProcessor):
         by_category = summary.get("by_category", {})
         detections = summary.get("detections", [])
         frame_key = str(frame_number) if frame_number is not None else "current_frame"
+        print("-----------ALERTTTTTTTTTTTTSSSSS-----------")
+        print(hasattr(config.alert_config, 'count_thresholds'), config.alert_config.count_thresholds)
+        print(total)
+        print(summary.get("per_category_count", {}))
 
         if total == 0:
             return []
         if not config.alert_config:
             return alerts
+        
 
         if hasattr(config.alert_config, 'count_thresholds') and config.alert_config.count_thresholds:
 
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category == "all" and total > threshold:  
-
+                    print("-----------ALERTS--INNN-----------")
                     alerts.append({
                         "alert_type": getattr(config.alert_config, 'alert_type', ['Default']) if hasattr(config.alert_config, 'alert_type') else ['Default'],
                         "alert_id": "alert_"+category+'_'+frame_key,
@@ -279,6 +295,7 @@ class FireSmokeUseCase(BaseProcessor):
                                     }                    
                     })
                 elif category in summary.get("per_category_count", {}):
+                    print("-----------ALERTS--INNN 2-----------")
                     count = summary.get("per_category_count", {})[category]
                     if count > threshold:  # Fixed logic: alert when EXCEEDING threshold
                         alerts.append({
@@ -318,6 +335,9 @@ class FireSmokeUseCase(BaseProcessor):
         current_timestamp = self._get_current_timestamp_str(stream_info)
         camera_info = self.get_camera_info_from_stream(stream_info)
         self._ascending_alert_list = self._ascending_alert_list[-900:] if len(self._ascending_alert_list) > 900 else self._ascending_alert_list
+        print("-----------INCIDENTS-----------")
+        print(total)
+        print(summary.get("per_category_count", {}))
 
         if total > 0:
            # Calculate total bbox area
@@ -325,6 +345,7 @@ class FireSmokeUseCase(BaseProcessor):
 
             for category, threshold in config.alert_config.count_thresholds.items():
                 if category in summary.get("per_category_count", {}):
+                    print("-----------INCIDENTSS--INNN-----------")
                     #count = summary.get("per_category_count", {})[category]
                     start_timestamp = self._get_start_timestamp_str(stream_info)
                     if start_timestamp and self.current_incident_end_timestamp=='N/A':
@@ -353,10 +374,10 @@ class FireSmokeUseCase(BaseProcessor):
                     intensity_pct = min(100.0, (total_area / threshold_area) * 100)
 
                     if config.alert_config and config.alert_config.count_thresholds:
-                            if intensity_pct >= 60:
+                            if intensity_pct >= 40:
                                 level = "critical"
                                 self._ascending_alert_list.append(3)
-                            elif intensity_pct >= 40:
+                            elif intensity_pct >= 30:
                                 level = "significant"
                                 self._ascending_alert_list.append(2)
                             elif intensity_pct >= 5:
@@ -366,11 +387,11 @@ class FireSmokeUseCase(BaseProcessor):
                                 level = "low"
                                 self._ascending_alert_list.append(0)
                     else:
-                            if intensity_pct > 60:
+                            if intensity_pct > 40:
                                 level = "critical"
                                 intensity = 10.0
                                 self._ascending_alert_list.append(3)
-                            elif intensity_pct > 40:
+                            elif intensity_pct > 30:
                                 level = "significant"
                                 intensity = 9.0
                                 self._ascending_alert_list.append(2)
@@ -404,6 +425,7 @@ class FireSmokeUseCase(BaseProcessor):
                             severity_level=level, human_text=human_text, camera_info=camera_info, alerts=alerts, alert_settings=alert_settings,
                             start_time=start_timestamp, end_time=self.current_incident_end_timestamp,
                             level_settings= {"low": 1, "medium": 5, "significant":40, "critical": 60})
+                    event['duration'] = self.get_duration_seconds(start_timestamp, self.current_incident_end_timestamp)
                     incidents.append(event)
 
         else:
@@ -573,11 +595,17 @@ class FireSmokeUseCase(BaseProcessor):
                 det for det in data
                 if det.get("category", "").lower() in valid_categories
             ]
+            counts = {}
+            for det in detections:
+                cat = det.get('category', 'unknown')
+                counts[cat] = counts.get(cat, 0) + 1
+            
 
             summary = {
                 "total_objects": len(detections),
                 "by_category": {},
                 "detections": detections,
+                "per_category_count": counts,
             }
 
             # Count by each category defined in config
@@ -831,5 +859,52 @@ class FireSmokeUseCase(BaseProcessor):
         dt = datetime.fromtimestamp(timestamp, tz=timezone.utc)
         return dt.strftime('%Y:%m:%d %H:%M:%S')
 
+    def get_duration_seconds(self, start_time, end_time):
+        def parse_relative_time(t):
+            """Parse HH:MM:SS(.f) manually into timedelta"""
+            try:
+                parts = t.strip().split(":")
+                if len(parts) != 3:
+                    return None
+                hours = int(parts[0])
+                minutes = int(parts[1])
+                seconds = float(parts[2])  # works for 7.4
+                return timedelta(hours=hours, minutes=minutes, seconds=seconds)
+            except:
+                return None
+
+        def parse_time(t):
+            # Check for HH:MM:SS(.ms) format
+            if re.match(r'^\d{1,2}:\d{2}:\d{1,2}(\.\d+)?$', t):
+                return parse_relative_time(t)
+
+            # Check for full UTC format like 2025-08-01-14:23:45.123456 UTC
+            if "UTC" in t:
+                try:
+                    return datetime.strptime(t, "%Y-%m-%d-%H:%M:%S.%f UTC")
+                except ValueError:
+                    return None
+
+            return None
+
+        start_dt = parse_time(start_time)
+        end_dt = parse_time(end_time)
+
+        # Return None if invalid
+        if start_dt is None or end_dt is None:
+            print("Invalid timestamp(s). Ignoring.")
+            return 'N/A'
+
+        # If timedelta (relative time), subtract directly
+        if isinstance(start_dt, timedelta) and isinstance(end_dt, timedelta):
+            delta = end_dt - start_dt
+        elif isinstance(start_dt, datetime) and isinstance(end_dt, datetime):
+            delta = end_dt - start_dt
+        else:
+            print("Mismatched timestamp formats.")
+            return None
+
+        return delta.total_seconds()
+
 
 
